@@ -37,12 +37,10 @@ def get_url_from_gdrive_confirmation(contents):
             url = "https://docs.google.com" + m.groups()[0]
             url = url.replace("&amp;", "&")
             break
-        m = re.search("confirm=([^;&]+)", line)
+        m = re.search('id="downloadForm" action="(.+?)"', line)
         if m:
-            confirm = m.groups()[0]
-            url = re.sub(
-                r"confirm=([^;&]+)", r"confirm={}".format(confirm), url
-            )
+            url = m.groups()[0]
+            url = url.replace("&amp;", "&")
             break
         m = re.search('"downloadUrl":"([^"]+)', line)
         if m:
@@ -222,9 +220,7 @@ def download(
             tmp_file = existing_tmp_files[0]
         else:
             resume = False
-            # mkstemp is preferred, but does not work on Windows
-            # https://github.com/wkentaro/gdown/issues/153
-            tmp_file = tempfile.mktemp(
+            _, tmp_file = tempfile.mkstemp(
                 suffix=tempfile.template,
                 prefix=osp.basename(output),
                 dir=osp.dirname(output),
